@@ -33,6 +33,7 @@
       'horizon.dashboard.container-infra.cluster-templates.details'
     ])
     .constant('horizon.dashboard.container-infra.cluster-templates.events', events())
+    .constant('horizon.dashboard.container-infra.cluster-templates.distros', distros())
     .constant(
       'horizon.dashboard.container-infra.cluster-templates.resourceType',
       'OS::Magnum::ClusterTemplate')
@@ -52,6 +53,16 @@
     };
   }
 
+  /**
+   * @ngdoc constant
+   * @name distros
+   * @return [distros] available image distros
+   * @description A list available image distros for magnum
+  */
+  function distros() {
+    return ["coreos", "fedora-atomic", "fedora-coreos", "ubuntu"];
+  }
+
   run.$inject = [
     'horizon.framework.conf.resource-type-registry.service',
     'horizon.dashboard.container-infra.cluster-templates.service',
@@ -62,7 +73,7 @@
   function run(registry, clusterTemplatesService, basePath, resourceType) {
     registry.getResourceType(resourceType)
     .setNames(gettext('Cluster Template'), gettext('Cluster Templates'))
-
+    .setDefaultIndexUrl('/project/cluster_templates/')
     // for detail summary view on table row
     .setSummaryTemplateUrl(basePath + 'details/drawer.html')
     // for table row items and detail summary view.
@@ -126,6 +137,7 @@
       'singleton': true,
       options: [
         {label: gettext('Docker Swarm'), key: 'swarm'},
+        {label: gettext('Docker Swarm Mode'), key: 'swarm-mode'},
         {label: gettext('Kubernetes'), key: 'kubernetes'},
         {label: gettext('DC/OS'), key: 'dcos'},
         {label: gettext('Mesos'), key: 'mesos'}
