@@ -60,7 +60,7 @@
   function run(registry, clustersService, basePath, resourceType) {
     registry.getResourceType(resourceType)
     .setNames(gettext('Cluster'), gettext('Clusters'))
-
+    .setDefaultIndexUrl('/project/clusters/')
     // for detail summary view on table row.
     .setSummaryTemplateUrl(basePath + 'details/drawer.html')
     // for table row items and detail summary view.
@@ -73,6 +73,9 @@
     .setProperty('status', {
       label: gettext('Status')
     })
+    .setProperty('health_status', {
+      label: gettext('Health Status')
+    })
     .setProperty('master_count', {
       label: gettext('Master Count')
     })
@@ -99,6 +102,10 @@
       id: 'status',
       priority: 1
     })
+    .append({
+      id: 'health_status',
+      priority: 1
+    })
     .append({
       id: 'master_count',
       priority: 2
@@ -146,6 +153,11 @@
         {label: gettext('UPDATE IN PROGRESS'), key: 'UPDATE_IN_PROGRESS'}
       ]
     })
+    .append({
+      'label': gettext('Health Status'),
+      'name': 'health_status',
+      'singleton': true
+    })
     .append({
       'label': gettext('Master Count'),
       'name': 'master_count',
