@@ -89,16 +89,17 @@
           'master_flavor_id': { type: 'string' },
           'node_count': {
             type: 'number',
-            minimum: 1
+            minimum: 0
           },
           'flavor_id': { type: 'string' },
           'auto_scaling_enabled': { type: 'boolean' },
           'min_node_count': {
             type: 'number',
-            minimum: 1
+            minimum: 0
           },
           'max_node_count': { type: 'number' },
 
+          'master_lb_enabled': {type: 'boolean'},
           'create_network': { type: 'boolean' },
           'fixed_network': { type: 'string' },
           'floating_ip_enabled': { type: 'boolean' },
@@ -320,6 +321,11 @@
                       type: 'fieldset',
                       title: gettext('Network'),
                       items: [
+                        {
+                          key: 'master_lb_enabled',
+                          type: 'checkbox',
+                          title: gettext('Enable Load Balancer for Master Nodes')
+                        },
                         {
                           key: 'create_network',
                           title: gettext('Create New Network'),
@@ -445,9 +451,9 @@
                           type: 'template',
                           template: '<div class="alert alert-warning">' +
                             '<span class="fa fa-warning"></span> ' +
-                            gettext('Overriding labels already defined by cluster template or' +
-                              'workflow might result in unpredictable behaviour.') +
-                            '</div>',
+                            gettext('Overriding labels already defined by the cluster ' +
+                            'template or workflow might result in unpredictable ' +
+                            'behaviour.') + '</div>',
                           condition: 'model.override_labels == true'
                         }
                       ]
@@ -477,6 +483,7 @@
           min_node_count: null,
           max_node_count: null,
 
+          master_lb_enabled: false,
           create_network: true,
           fixed_network: '',
           floating_ip_enabled: false,
